Properties Methods Events Config Options Direct Link

# Class Ext.ensible.cal.CalendarListMenu

Package: | Ext.ensible.cal
Defined In: | CalendarListMenu.js
Class: | CalendarListMenu
Extends: | Object

A menu containing a palette for choosing calendar colors, as well as other calendar-specific options.

## Config Options

Config Options | Defined By
--- | ---
| calendarId : Number The id of the calendar to be associated with this menu. This calendarId will be passed back with any events from this... The id of the calendar to be associated with this menu. This calendarId will be passed back with any events from this menu to identify the calendar to be acted upon. The calendar id can also be changed at any time after creation by calling setCalendar. | CalendarListMenu
| cls : String An optional extra CSS class that will be added to this component's Element (defaults to 'x-calendar-list-menu'). Thi... An optional extra CSS class that will be added to this component's Element (defaults to 'x-calendar-list-menu'). This can be useful for adding customized styles to the component or any of its children using standard CSS rules. | CalendarListMenu
| displayOnlyThisCalendarText : String The text to display for the 'Display only this calendar' option in the menu. | CalendarListMenu
| hideOnClick : Boolean False to continue showing the menu after a color is selected, defaults to true. | CalendarListMenu
| ignoreParentClicks : Boolean True to ignore clicks on any item in this menu that is a parent item (displays a submenu) so that the submenu is not... True to ignore clicks on any item in this menu that is a parent item (displays a submenu) so that the submenu is not dismissed when clicking the parent item (defaults to true). | CalendarListMenu

## Public Properties

Property | Defined By
--- | ---
| palette : ColorPalette The {@link Ext.ensible.cal.ColorPalette ColorPalette} instance for this CalendarListMenu | CalendarListMenu

## Public Methods

Method | Defined By
--- | ---
| setCalendar( `Number calendarId`, `Number colorId` ) : Ext.ensible.cal.CalendarListMenu Sets the calendar id and color id to be associated with this menu. This should be called each time the menu is shown ... Sets the calendar id and color id to be associated with this menu. This should be called each time the menu is shown relative to a new calendar. Parameters: `calendarId` : Number The id of the calendar to be associated `colorId` : Number The id of the color to be pre-selected in the color palette Returns: `Ext.ensible.cal.CalendarListMenu` this | CalendarListMenu

## Public Events

This class has no public events.